@@ -7,20 +7,21 @@
 
 import datetime
 import os.path
+import posixpath
 import shutil
 import tempfile
 import time
 
-import pytest
-
 import pandas
-
-from .util import assert_items_equal
+import pytest
 from intake import open_catalog
 from intake.catalog import exceptions, local
-from intake.catalog.local import get_dir, UserParameter, LocalCatalogEntry
+from intake.catalog.local import LocalCatalogEntry, UserParameter, get_dir
+from intake.tests.test_utils import copy_test_file
 from intake.utils import make_path_posix
 
+from .util import assert_items_equal
+
 
 def abspath(filename):
     return make_path_posix(
@@ -248,6 +249,42 @@ def test_user_parameter_validation_allowed():
     assert 'allowed' in str(except_info.value)
 
 
+def test_user_pars_list():
+    # first case: allowed are all lists, must choose exactly one of them
+    # NB: order must match
+    p = local.UserParameter("", "", "list",
+                            allowed=[[], ["one"], ["one", "two"]])
+    with pytest.raises(TypeError):
+        p.validate(0)
+    with pytest.raises((TypeError, ValueError)):
+        # unfortunately, a string does coerce to a list
+        p.validate("one")
+    with pytest.raises(ValueError, match="allowed"):
+        p.validate(["two"])
+    with pytest.raises(ValueError, match="allowed"):
+        p.validate(["two", "one"])
+    p.validate(["one"])
+    p.validate(["one", "two"])
+
+
+def test_user_pars_mlist():
+    # second case: allowed are not lists, can choose any number of them
+    # NB: repeats are allowed
+    p = local.UserParameter("", "", "mlist",
+                            allowed=["one", "two", "three"])
+    with pytest.raises(TypeError):
+        p.validate(0)
+    with pytest.raises((TypeError, ValueError)):
+        # unfortunately, a string does coerce to a list
+        p.validate("one")
+    with pytest.raises(ValueError, match="allowed"):
+        p.validate(["two" ,"other"])
+    p.validate(["two"])
+    p.validate(["two", "two"])
+    p.validate(["two", "one"])
+    p.validate([])
+
+
 @pytest.mark.parametrize("filename", [
     "catalog_non_dict",
     "data_source_missing",
@@ -764,3 +801,42 @@ def test_cat_dictlike(catalog1):
     assert list(catalog1) == list(catalog1.keys())
     assert len(list(catalog1)) == len(catalog1)
     assert list(catalog1.items()) == list(zip(catalog1.keys(), catalog1.values()))
+
+
+def test_inherit_params(inherit_params_cat):
+    assert inherit_params_cat.param._urlpath == "s3://test_bucket/file.parquet"
+
+
+def test_runtime_overwrite_params(inherit_params_cat):
+    assert (
+        inherit_params_cat.param(bucket="runtime_overwrite")._urlpath
+        == "s3://runtime_overwrite/file.parquet"
+    )
+
+
+def test_local_param_overwrites(inherit_params_cat):
+    assert (
+        inherit_params_cat.local_param_overwrites._urlpath
+        == "s3://local_param/file.parquet"
+    )
+
+
+def test_local_and_global_params(inherit_params_cat):
+    assert (
+        inherit_params_cat.local_and_global_params._urlpath
+        == "s3://test_bucket/local_filename.parquet"
+    )
+
+
+def test_search_inherit_params(inherit_params_cat):
+    assert (
+        inherit_params_cat.search("local_and_global").local_and_global_params._urlpath
+        == "s3://test_bucket/local_filename.parquet"
+    )
+
+
+def test_multiple_cats_params(inherit_params_multiple_cats):
+    assert (
+        inherit_params_multiple_cats.local_and_global_params._urlpath
+        == "s3://test_bucket/local_filename.parquet"
+    )
