@@ -13,7 +13,8 @@ import pandas as pd
 
 from intake.source.tests.util import verify_datasource_interface
 from .util import assert_items_equal
-from intake import open_catalog, RemoteCatalog
+from intake import open_catalog
+from intake.catalog.remote import RemoteCatalog
 
 TEST_CATALOG_PATH = os.path.join(os.path.dirname(__file__), 'catalog1.yml')
 
@@ -121,7 +122,6 @@ def test_read(intake_server):
     meta = expected_df[:0]
 
     info = d.discover()
-    assert info['datashape'] is None
     assert info['dtype'] == {k: str(v) for k, v
                              in meta.dtypes.to_dict().items()}
     assert info['npartitions'] == 2
@@ -147,7 +147,6 @@ def test_read_direct(intake_server):
 
     info = d.discover()
 
-    assert info['datashape'] is None
     assert info['dtype'] == {k: str(v) for k, v
                              in meta.dtypes.to_dict().items()}
     assert info['npartitions'] == 1
