@@ -8,23 +8,9 @@
 CLI for listing, enabling, disabling intake drivers
 """
 
-
-# -----------------------------------------------------------------------------
-# Imports
-# -----------------------------------------------------------------------------
-
-# Standard library imports
-import inspect
-import sys
-
-# External imports
-
-# Intake imports
 from intake import __version__
 from intake.cli.util import Subcommand
-from intake.source.discovery import autodiscover, autodiscover_all, enable, disable
-from intake.config import confdir
-import intake
+from intake.source.discovery import drivers
 
 import logging
 log = logging.getLogger(__name__)
@@ -55,7 +41,7 @@ class Drivers(Subcommand):
 
         enable = sub_parser.add_parser('enable', help='Enable an intake driver.')
         enable.add_argument('name', type=str, help='Driver name')
-        enable.add_argument('driver', type=str,
+        enable.add_argument('driver', type=str, default=None, nargs='?',
                             help='Module path and class name, as in '
                                  'package.submodule.ClassName')
         enable.set_defaults(invoke=self._enable)
@@ -69,53 +55,38 @@ class Drivers(Subcommand):
         self.parser.print_help()
 
     def _list(self, args):
-        if args.verbose:
-            fmt = '{name:<30}{cls.__module__}.{cls.__name__} @ {file}'
+        if drivers.do_scan:
+            print("Package scan:")
+            for k, v in drivers.scanned.items():
+                print(f'{k:<30}{v.__module__}.{v.__name__}')
+            print()
+
+        print("Entrypoints:")
+        eps = [ep for ep in drivers.from_entrypoints()
+               if ep.name not in drivers.disabled()]
+        if eps:
+            for v in eps:
+                print(f'{v.name:<30}{v.module_name}:{v.object_name}')
         else:
-            fmt = '{name:<30}{cls.__module__}.{cls.__name__}'
-        drivers_by_name = autodiscover()   # dict mapping name to driver
-        all_drivers = autodiscover_all()  # listof (name, driver)
-        direct = {}
-        for k in intake.registry:
-            if k not in all_drivers and k not in drivers_by_name:
-                try:
-                    direct[k] = intake.registry[k]
-                except ImportError:
-                    pass
-
-        print("Direct:", file=sys.stderr)
-        none = True
-        for name in sorted(direct, key=str):
-            cls = direct[name]
-            print(fmt.format(name=str(name), cls=cls, file=inspect.getfile(cls)),
-                  file=sys.stderr)
-            none = False
-        if none:
             print("<none>")
+        print()
 
-        print("\nEnabled:", file=sys.stderr)
-        none = True
-        for name in sorted(drivers_by_name, key=str):
-            cls = drivers_by_name[name]
-            print(fmt.format(name=str(name), cls=cls, file=inspect.getfile(cls)),
-                  file=sys.stderr)
-            none = False
-        if none:
+        print("From Config:")
+        eps = [ep for ep in drivers.from_conf()
+               if ep.name not in drivers.disabled()]
+        if eps:
+            for v in eps:
+                if v.name not in drivers.disabled():
+                    print(f'{v.name:<30}{v.module_name}:{v.object_name}')
+        else:
             print("<none>")
+        print()
 
-        print("\nNot enabled:", file=sys.stderr)
-        none = True
-        for name, cls in sorted(all_drivers, key=lambda x: str(x[0])):
-            if drivers_by_name.get(name, None) is not cls:
-                print(fmt.format(name=str(name), cls=cls, file=inspect.getfile(cls)),
-                      file=sys.stderr)
-                none = False
-        if none:
-            print("<none>")
+        print("Disabled: ", drivers.disabled() or "<none>")
 
     def _enable(self, args):
-        enable(args.name, args.driver)
+        drivers.enable(args.name, args.driver)
 
     def _disable(self, args):
         for name in args.names:
-            disable(name)
+            drivers.disable(name)
