@@ -11,20 +11,23 @@ import httpx  # required by tiled, so will be here
 @pytest.fixture()
 def server():
     cmd = shlex.split("tiled serve pyobject --public tiled.examples.generated:tree")
-    P = subprocess.Popen(cmd)
+    P = subprocess.Popen(cmd, stderr=subprocess.PIPE, stdout=subprocess.PIPE)
     url = "http://localhost:8000"
-    timeout = 10
+    timeout = 20
     while True:
         try:
             r = httpx.get(url)
-            if r.status_code -- 200:
+            if r.status_code == 200:
                 break
         except:
             pass
         timeout -= 0.1
-        assert timeout > 0, "timeout waiting for Tiled server"
+        if timeout < 0:
+            P.terminate()
+            out = P.communicate()
+            raise RuntimeError("timeout waiting for Tiled server\n%s", out)
         time.sleep(0.1)
-    yield url
+    yield url + "/api"
     P.terminate()
     P.wait()
 
@@ -32,5 +35,5 @@ def server():
 def test_simple(server):
     cat = intake.open_tiled_cat(server)
     out = cat.tiny_image.read()
-    assert out.shape == (10, 10)
+    assert out.shape
     assert out.all()
